==> haskell-smtlib-1.0.9-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-smtlib.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: smtLib
version: 1.0.9
id: smtLib-1.0.9-6lVLttiPvFoKIXzisleky0
key: smtLib-1.0.9-6lVLttiPvFoKIXzisleky0
license: BSD3
maintainer: iavor.diatchki@gmail.com
synopsis: A library for working with the SMTLIB format.
description:
    A library for working with the SMTLIB format.
category: SMT
author: Iavor S. Diatchki
exposed: True
indefinite: False
exposed-modules:
    SMTLib1 SMTLib1.QF_AUFBV SMTLib1.QF_BV SMTLib2 SMTLib2.Array
    SMTLib2.BitVector SMTLib2.Compat1 SMTLib2.Core SMTLib2.Int
hidden-modules: SMTLib1.AST SMTLib1.PP SMTLib2.AST SMTLib2.PP
abi: d762abe4e419cfebe8915f273f9e776c
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/smtLib-1.0.9
library-dirs: /usr/lib/ghc-8.2.2/site-local/smtLib-1.0.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/smtLib-1.0.9
hs-libraries: HSsmtLib-1.0.9-6lVLttiPvFoKIXzisleky0
depends:
    base-4.10.1.0 pretty-1.1.3.3
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             pretty-1.1.3.3=229bcf5342145ac1755207fe83d29780
haddock-interfaces: /usr/share/doc/haskell-smtlib/html/smtLib.haddock
haddock-html: /usr/share/doc/haskell-smtlib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-smtlib-1.0.9-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-smtlib.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: smtLib
version: 1.0.9
id: smtLib-1.0.9-6vwf9of4gDxCqBtFifNi4C
key: smtLib-1.0.9-6vwf9of4gDxCqBtFifNi4C
license: BSD-3-Clause
maintainer: iavor.diatchki@gmail.com
author: Iavor S. Diatchki
synopsis: A library for working with the SMTLIB format.
description:
    A library for working with the SMTLIB format.
category: SMT
abi: 2a791833a7cf929504a9d639e4eebd64
exposed: True
exposed-modules:
    SMTLib1 SMTLib1.QF_AUFBV SMTLib1.QF_BV SMTLib2 SMTLib2.Array
    SMTLib2.BitVector SMTLib2.Compat1 SMTLib2.Core SMTLib2.Int
hidden-modules: SMTLib1.AST SMTLib1.PP SMTLib2.AST SMTLib2.PP
import-dirs: /usr/lib/ghc-8.4.3/site-local/smtLib-1.0.9
library-dirs: /usr/lib/ghc-8.4.3/site-local/smtLib-1.0.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/smtLib-1.0.9
hs-libraries: HSsmtLib-1.0.9-6vwf9of4gDxCqBtFifNi4C
depends:
    base-4.11.1.0 pretty-1.1.3.6
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             pretty-1.1.3.6=3c31686bd534e1773b954ae82713db97
haddock-interfaces: /usr/share/doc/haskell-smtlib/html/smtLib.haddock
haddock-html: /usr/share/doc/haskell-smtlib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
